==> popper.js-1.12.5.jar: META-INF/resources/webjars/popper.js/1.12.5/packages/popper/bundle.js <==
const bundle = require('@popperjs/bundle');

const banner = `/**!
 * @fileOverview Kickass library to create and place poppers near their reference elements.
 * @version ${require('./package.json').version}
 * @license
 * Copyright (c) 2016 Federico Zivolo and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */`;

const miniBanner = `/*
 Copyright (C) Federico Zivolo ${new Date().getFullYear()}
 Distributed under the MIT License (license terms are at http://opensource.org/licenses/MIT).
 */`

bundle({
  moduleName: 'Popper',
  entry: 'src/index.js',
  dest: 'popper.js',
  banner,
  miniBanner,
});

bundle({
  moduleName: 'PopperUtils',
  entry: 'src/utils/index.js',
  dest: 'popper-utils.js',
  banner,
  miniBanner,
});

==> popper.js-1.15.0.jar: META-INF/resources/webjars/popper.js/1.15.0/packages/popper/bundle.js <==
const bundle = require('@popperjs/bundle');

const banner = `/**!
 * @fileOverview Kickass library to create and place poppers near their reference elements.
 * @version ${require('./package.json').version}
 * @license
 * Copyright (c) 2016 Federico Zivolo and contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */`;

const miniBanner = `/*
 Copyright (C) Federico Zivolo ${new Date().getFullYear()}
 Distributed under the MIT License (license terms are at http://opensource.org/licenses/MIT).
 */`

bundle({
  name: 'Popper',
  input: 'src/index.js',
  file: 'popper.js',
  banner,
  miniBanner,
});

bundle({
  name: 'PopperUtils',
  input: 'src/utils/index.js',
  file: 'popper-utils.js',
  banner,
  miniBanner,
});
